<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Duplicada</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Extendida</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Solo en %1</translation>
    </message>
</context>
</TS>